//
//  ViewController.swift
//  iBeaconHotCold
//
//  Created by Dheeraj T on 2017-02-11.
//  Copyright © 2017 Dheeraj T. All rights reserved.
//

import UIKit
import CoreLocation
import CoreBluetooth




class ViewController: UIViewController, CLLocationManagerDelegate, CBPeripheralManagerDelegate {
    @IBOutlet weak var WebView: UIWebView!

    var locationManager: CLLocationManager!
    var blueToothmanager:CBPeripheralManager!

    @IBOutlet weak var hotColdLabel: UILabel!
    
    override func viewDidLoad() {
        super.viewDidLoad()
        print("View Did Load")
        // Do any additional setup after loading the view, typically from a nib.

        
        blueToothmanager = CBPeripheralManager(delegate: self, queue: nil)
        locationManager = CLLocationManager()
        locationManager.delegate = self
        locationManager.requestWhenInUseAuthorization()
    }

    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }
    
    func locationManager(_ manager: CLLocationManager, didChangeAuthorization status: CLAuthorizationStatus) {
        if status == .authorizedWhenInUse {
            if CLLocationManager.isMonitoringAvailable(for: CLBeaconRegion.self) {
                if CLLocationManager.isRangingAvailable() {
                    print("Starting Scan")
                    startScanning()
                }
            }
        }
    }
    
    //default UUID of our beacons: "F7826DA6-4FA2-4E98-8024-BC5B71E0893E"
    func startScanning() {
        let uuid = UUID(uuidString: "E2C56DB5-DFFB-48D2-B060-D0F5A71096E0")!
        let beaconRegion = CLBeaconRegion(proximityUUID: uuid, major: 0, minor: 2,identifier: "iBeacon")
        
//        let uuid2 = UUID(uuidString: "5A4BCFCE-174E-4BAC-A814-092E77F6B7E6")!
//        let beaconRegion2 = CLBeaconRegion(proximityUUID: uuid2, major: 123, minor: 456,identifier: "iBeacon2")

        beaconRegion.notifyOnEntry = true
        beaconRegion.notifyOnExit = true
        locationManager.startMonitoring(for: beaconRegion)
        locationManager.startRangingBeacons(in: beaconRegion)
        
        //for  beacon2
//        beaconRegion2.notifyOnEntry = true
//        beaconRegion2.notifyOnExit = true
//        locationManager.startMonitoring(for: beaconRegion2)
//        locationManager.startRangingBeacons(in: beaconRegion2)
    }
    
    func locationManager(_ manager: CLLocationManager, didRangeBeacons beacons: [CLBeacon], in region: CLBeaconRegion) {
        if beacons.count > 0 {
            print(beacons)
            updateDistance(beacons[0].proximity)
        } else {
            print("No beacons in region")
            updateDistance(.unknown)
        }
    }
    
    var Acutualcurrent = "Active"
    var Unknown_current = "Active"
    var Far_current = "Active"
    var Near_current = "Active"
    var Immediate_current = "Active"

    
    func updateDistance(_ distance: CLProximity) {
        //print("Updating Distance")
    

        UIView.animate(withDuration: 0.5) {
            switch distance {
            case .unknown:
                
                if self.Unknown_current == self.Acutualcurrent {
                    
                    let homepage_url = URL(string: "https://draj.me/react/index.php")
                    let homepage_request = URLRequest(url: homepage_url!)
                    self.WebView.loadRequest(homepage_request)
                    self.Unknown_current = "Active_Logged"
            
                }else{
                    self.Far_current = "Active"
                    self.Near_current = "Active"
                    self.Immediate_current = "Active"
                     
                }
        
            case .far:
                //self.view.backgroundColor = UIColor.blue;
                //self.hotColdLabel.text = "Colder. ~ In Product Zone"
                
                if self.Far_current == self.Acutualcurrent {
                    
                    let homepage_url = URL(string: "https://draj.me/react/category.php")
                    let homepage_request = URLRequest(url: homepage_url!)
                    self.WebView.loadRequest(homepage_request)
                    self.Far_current = "Active_Logged"
                    
                }else{
                    self.Unknown_current = "Active"
                    self.Near_current = "Active"
                    self.Immediate_current = "Active"
                }
                
                
            case .near:
                
                
                if self.Near_current == self.Acutualcurrent {
                    
                    let homepage_url = URL(string: "https://draj.me/react/product.php")
                    let homepage_request = URLRequest(url: homepage_url!)
                    self.WebView.loadRequest(homepage_request)
                    self.Near_current = "Active_Logged"
                    
                }else{
                    self.Unknown_current = "Active"
                    self.Far_current = "Active"
                    self.Immediate_current = "Active"
                }
                
                
                
            case .immediate:
                
                if self.Immediate_current == self.Acutualcurrent {
                    
                    let homepage_url = URL(string: "https://draj.me/react/checkout.php")
                    let homepage_request = URLRequest(url: homepage_url!)
                    self.WebView.loadRequest(homepage_request)
                    self.Immediate_current = "Active_Logged"
                    
                }else{
                    self.Unknown_current = "Active"
                    self.Far_current = "Active"
                    self.Near_current = "Active"
                    
                }
                
                
            }
        }
    }
    
    func locationManager(_ manager: CLLocationManager, didEnterRegion region: CLRegion) {
        if let beaconRegion = region as? CLBeaconRegion {
            print("DID ENTER REGION: uuid: \(beaconRegion.proximityUUID.uuidString)")
        }
    }
    
    
    func locationManager(_ manager: CLLocationManager, didExitRegion region: CLRegion) {
        if let beaconRegion = region as? CLBeaconRegion {
            print("DID EXIT REGION: uuid: \(beaconRegion.proximityUUID.uuidString)")
        }
    }
    
    func alert(message: String, title: String = "Blue Tooth Status")
    {
        let alertController = UIAlertController(title: title, message: message, preferredStyle: .alert)
        let OKAction = UIAlertAction(title: "OK", style: .default, handler: nil)
        alertController.addAction(OKAction)
        self.present(alertController, animated: true, completion: nil)
    }
    
    func peripheralManagerDidUpdateState(_ peripheral: CBPeripheralManager) {
        
        var statusMessage = ""
        
        switch peripheral.state {
        case .poweredOn:
            statusMessage = "Blue Tooth is turned on."
            
        case .poweredOff:
            statusMessage = "Please turn on Blue Tooth.";
            alert(message: statusMessage)
            
        case .resetting:
            statusMessage = "Resetting."
            
        case .unauthorized:
            statusMessage = "Please Authorize Blue Tooth."
            alert(message: statusMessage)
            
        case .unsupported:
            statusMessage = "Blue Tooth Is Not Supported on this device."
            alert(message: statusMessage)
            
        default:
            statusMessage = "Unknown"
        }
        
        print(statusMessage)
    }
    
    func locationManager(_ manager: CLLocationManager, monitoringDidFailFor region: CLRegion?, withError error: Error){
        print("monitoringDidFailFor")
    }
    
    func locationManager(_ manager: CLLocationManager, rangingBeaconsDidFailFor region: CLBeaconRegion, withError error: Error){
        print("rangingBeaconsDidFailFor")

    }
}

